@@ -10,19 +10,22 @@ from ..command import Command
 
 if ty.TYPE_CHECKING:
    from .. import FluxClient
+   from ..context import MessageContext
    from ..command import Response
+   from ..types_ import *
+
 
 class FluxCog:
    def __init__(self, flux: FluxClient, name: ty.Optional[str] = None):
       self.name = name or self.__class__.__name__
       self.flux = flux
       self.router = aur.EventRouter(self.name, host=self.flux.router.host)
-      self.command_names = set()
+      self.command_names: ty.Set[str] = set()
       logger.info(f"{self.name} loaded! Under {self.router}")
       self.load()
 
-   def _commandeer(self, name: ty.Optional[str] = None, parsed: bool = True, private: bool = False) -> ty.Callable[[ty.Callable[[...], ty.Awaitable[Response]]], Command]:
-      def command_deco(func: ty.Callable[[...], ty.Awaitable[Response]]) -> Command:
+   def _commandeer(self, name: ty.Optional[str] = None, parsed: bool = True, private: bool = False) -> ty.Callable[[CommandFunc], Command]:
+      def command_deco(func: CommandFunc) -> Command:
          cmd = Command(flux=self.flux, func=func, name=(name or func.__name__), parsed=parsed, private=private)
          if cmd.name in self.command_names:
             raise TypeError(f"Attempting to register command {cmd} when one with the same name already exists")
